@@ -137,7 +137,7 @@ def find_python_in_context(context):
     # accidentally find a system python install.
     #
     context = context.copy()
-    context.append_sys_path = False  # GitHub nerdvegas/rez/issue/826
+    context.append_sys_path = False  # https://github.com/nerdvegas/rez/issues/826
 
     python_package = context.get_resolved_package("python")
     assert python_package
@@ -202,6 +202,9 @@ def find_pip_from_context(python_version, pip_version=None):
 
     py_exe = find_python_in_context(context)
 
+    if not py_exe:
+        return None, None, context
+
     proc = context.execute_command(
         # -E and -s are used to isolate the environment as much as possible.
         # See python --help for more details. We absolutely don't want to get
